==> lowcode-editor-skeleton-1.3.5.tgz: package/es/layouts/workbench.js <==
import _Splitter from "antd/lib/splitter";
import _inheritsLoose from "@babel/runtime/helpers/inheritsLoose";
var _class;
import { Component } from 'react';
import { TipContainer, observer } from '@gant-lowcode/lowcode-editor-core';
import classNames from 'classnames';
import TopArea from './top-area';
import LeftArea from './left-area';
import LeftFixedPane from './left-fixed-pane';
import LeftFloatPane from './left-float-pane';
import Toolbar from './toolbar';
import MainArea from './main-area';
import BottomArea from './bottom-area';
import RightArea from './right-area';
import './workbench.less';
import { SkeletonContext } from '../context';
export var Workbench = observer(_class = /*#__PURE__*/function (_Component) {
  function Workbench(props) {
    var _this;
    _this = _Component.call(this, props) || this;
    var _this$props = _this.props,
      config = _this$props.config,
      components = _this$props.components,
      skeleton = _this$props.skeleton;
    skeleton.buildFromConfig(config, components);
    return _this;
  }
  _inheritsLoose(Workbench, _Component);
  var _proto = Workbench.prototype;
  _proto.render = function render() {
    var _this$props2 = this.props,
      skeleton = _this$props2.skeleton,
      className = _this$props2.className,
      topAreaItemClassName = _this$props2.topAreaItemClassName;
    return /*#__PURE__*/React.createElement("div", {
      className: classNames('lc-workbench', className)
    }, /*#__PURE__*/React.createElement(SkeletonContext.Provider, {
      value: this.props.skeleton
    }, /*#__PURE__*/React.createElement("div", {
      className: "lc-workbench-body"
    }, /*#__PURE__*/React.createElement(LeftArea, {
      area: skeleton.leftArea
    }), /*#__PURE__*/React.createElement(LeftFloatPane, {
      area: skeleton.leftFloatArea
    }), /*#__PURE__*/React.createElement(LeftFixedPane, {
      area: skeleton.leftFixedArea
    }), /*#__PURE__*/React.createElement("div", {
      className: "lc-workbench-body-right"
    }, /*#__PURE__*/React.createElement(TopArea, {
      area: skeleton.topArea,
      itemClassName: topAreaItemClassName
    }), /*#__PURE__*/React.createElement(_Splitter, null, /*#__PURE__*/React.createElement(_Splitter.Panel, null, /*#__PURE__*/React.createElement("div", {
      className: "lc-workbench-center"
    }, /*#__PURE__*/React.createElement(Toolbar, {
      area: skeleton.toolbar
    }), /*#__PURE__*/React.createElement(MainArea, {
      area: skeleton.mainArea
    }), /*#__PURE__*/React.createElement(BottomArea, {
      area: skeleton.bottomArea
    }))), /*#__PURE__*/React.createElement(_Splitter.Panel, {
      defaultSize: 400,
      min: 400,
      max: '50%',
      className: "right-area-splitter-panel"
    }, /*#__PURE__*/React.createElement(RightArea, {
      area: skeleton.rightArea
    }))))), /*#__PURE__*/React.createElement(TipContainer, null)));
  };
  return Workbench;
}(Component)) || _class;

==> lowcode-editor-skeleton-2.0.0.tgz: package/es/layouts/workbench.js <==
import _inheritsLoose from "@babel/runtime/helpers/inheritsLoose";
var _class;
import { Component } from 'react';
import { TipContainer, observer } from '@gant-lowcode/lowcode-editor-core';
import classNames from 'classnames';
import TopArea from './top-area';
import LeftArea from './left-area';
import LeftFixedPane from './left-fixed-pane';
import LeftFloatPane from './left-float-pane';
import Toolbar from './toolbar';
import MainArea from './main-area';
import BottomArea from './bottom-area';
import RightArea from './right-area';
import './workbench.less';
import { SkeletonContext } from '../context';
export var Workbench = observer(_class = /*#__PURE__*/function (_Component) {
  function Workbench(props) {
    var _this;
    _this = _Component.call(this, props) || this;
    // 新增拖拽处理逻辑
    _this.handleSplitterMouseDown = function (e) {
      e.preventDefault();
      var startX = e.clientX;
      var startWidth = _this.state.width;
      _this.setState({
        startDrag: true
      });
      var doDrag = function doDrag(moveEvent) {
        // 计算横向移动距离并更新宽度
        var deltaX = moveEvent.clientX - startX;
        var newWidth = startWidth - deltaX;

        // 限制宽度在400px到800px之间
        _this.setState({
          width: Math.max(400, Math.min(800, newWidth))
        });
      };
      var _stopDrag = function stopDrag() {
        _this.setState({
          startDrag: false
        });
        document.removeEventListener('mousemove', doDrag);
        document.removeEventListener('mouseup', _stopDrag);
      };
      document.addEventListener('mousemove', doDrag);
      document.addEventListener('mouseup', _stopDrag);
    };
    var _this$props = _this.props,
      config = _this$props.config,
      components = _this$props.components,
      skeleton = _this$props.skeleton;
    skeleton.buildFromConfig(config, components);
    _this.state = {
      startDrag: false,
      width: 400
    };
    return _this;
  }
  _inheritsLoose(Workbench, _Component);
  var _proto = Workbench.prototype;
  _proto.render = function render() {
    var _this$props2 = this.props,
      skeleton = _this$props2.skeleton,
      className = _this$props2.className,
      topAreaItemClassName = _this$props2.topAreaItemClassName;
    return /*#__PURE__*/React.createElement("div", {
      className: classNames('lc-workbench', className)
    }, /*#__PURE__*/React.createElement(SkeletonContext.Provider, {
      value: this.props.skeleton
    }, /*#__PURE__*/React.createElement("div", {
      className: "lc-workbench-body"
    }, /*#__PURE__*/React.createElement(LeftArea, {
      area: skeleton.leftArea
    }), /*#__PURE__*/React.createElement(LeftFloatPane, {
      area: skeleton.leftFloatArea
    }), /*#__PURE__*/React.createElement(LeftFixedPane, {
      area: skeleton.leftFixedArea
    }), /*#__PURE__*/React.createElement("div", {
      className: "lc-workbench-body-right"
    }, /*#__PURE__*/React.createElement(TopArea, {
      area: skeleton.topArea,
      itemClassName: topAreaItemClassName
    }), /*#__PURE__*/React.createElement("div", {
      className: "lc-workbench-splitter"
    }, /*#__PURE__*/React.createElement("div", {
      className: "lc-workbench-center left-area-splitter-panel"
    }, /*#__PURE__*/React.createElement(Toolbar, {
      area: skeleton.toolbar
    }), /*#__PURE__*/React.createElement(MainArea, {
      area: skeleton.mainArea
    }), /*#__PURE__*/React.createElement(BottomArea, {
      area: skeleton.bottomArea
    })), /*#__PURE__*/React.createElement("div", {
      className: "splitter-bar",
      onMouseDown: this.handleSplitterMouseDown
    }, /*#__PURE__*/React.createElement("div", {
      className: "splitter-bar-dragger"
    })), /*#__PURE__*/React.createElement("div", {
      className: "right-area-splitter-panel",
      style: {
        width: this.state.width
      }
    }, /*#__PURE__*/React.createElement(RightArea, {
      area: skeleton.rightArea
    })), this.state.startDrag && /*#__PURE__*/React.createElement("div", {
      "aria-hidden": true,
      className: "splitter-mask"
    })))), /*#__PURE__*/React.createElement(TipContainer, null)));
  };
  return Workbench;
}(Component)) || _class;
